@@ -251,7 +251,7 @@ func makeSysInfoBody(distroTarget, namespace string, instanceData []byte, includ
 		}
 	}
 
-	sysinfo, err := fetchSystemInformation()
+	sysinfo, err := FetchSystemInformation()
 	if err != nil {
 		return nil, err
 	}
@@ -277,7 +277,7 @@ var mandatoryCollectors = []collectors.Collector{
 	collectors.SAP{},
 }
 
-func fetchSystemInformation() (collectors.Result, error) {
+func FetchSystemInformation() (collectors.Result, error) {
 	arch, err := collectors.DetectArchitecture()
 
 	if err != nil {
@@ -339,3 +339,17 @@ func installerUpdates(product Product) ([]zypper.Repository, error) {
 	}
 	return repos, nil
 }
+
+func setLabels(labels []Label) error {
+	var payload struct {
+		Labels []Label `json:"labels"`
+	}
+	payload.Labels = labels
+	body, err := json.Marshal(payload)
+
+	if err != nil {
+		return err
+	}
+	_, err = callHTTP("POST", "/connect/systems/labels", body, nil, authSystem)
+	return err
+}
