@@ -375,3 +375,46 @@ func TestMakeSysInfoBody(t *testing.T) {
 	assert.NoError(err)
 	assert.Equal(expectedBody, string(body))
 }
+
+func TestSetLabelsOk(t *testing.T) {
+	assert := assert.New(t)
+
+	testLabels := []Label{
+		Label{Name: "label1"},
+		Label{Name: "label2"},
+	}
+
+	setRootToTmp()
+	credentials.CreateTestCredentials("", "", CFG.FsRoot, t)
+
+	ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+		w.Write(util.ReadTestFile("set_labels.json", t))
+	}))
+	defer ts.Close()
+
+	CFG.BaseURL = ts.URL
+
+	err := setLabels(testLabels)
+	assert.NoError(err)
+}
+
+func TestSetLabelsError(t *testing.T) {
+	assert := assert.New(t)
+	testLabels := []Label{
+		Label{Name: "label1"},
+		Label{Name: "label2"},
+	}
+
+	setRootToTmp()
+	credentials.CreateTestCredentials("", "", CFG.FsRoot, t)
+
+	ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+		errMsg := "{\"status\":422,\"error\":\"Cannot set more than 10 labels on system: test-system\",\"type\":\"error\",\"localized_error\":\"Es können nicht mehr als 10 labels per System gesetzt werden: test-system\"}"
+		http.Error(w, errMsg, http.StatusUnprocessableEntity)
+	}))
+	defer ts.Close()
+	CFG.BaseURL = ts.URL
+
+	err := setLabels(testLabels)
+	assert.ErrorContains(err, "Es können")
+}
